@@ -1,7 +1,7 @@
 /************************************************************************
  * ifchk.c                                                              *
  *                                                                      *
- * Copyright (C) 2002 - 2018 Joshua Birnbaum <engineer@noorg.org>.      *
+ * Copyright (C) 2002 - 2019 Joshua Birnbaum <engineer@noorg.org>.      *
  * All Rights Reserved.                                                 *
  *                                                                      *
  * This program is free software; you can redistribute it and/or modify *
@@ -31,7 +31,7 @@
  * Project ifchk -- Host based network interface promiscuous  *
  *                  mode detection and handling.              *
  *                                                            *
- * Version:         1.1.0                                     *
+ * Version:         1.1.1                                     *
  *                                                            *
  * ---------------------------------------------------------- *
  *                                                            *
@@ -518,7 +518,7 @@ int main( int argc, char **argv )
      * If we're running as a foreground process, we
      * write a program termination message to STDOUT.
      */
-    printf( "ifchk[%d]: ifchk caught SIGINT or SIGTERM, exiting\n" );
+    printf( "ifchk[%d]: ifchk caught SIGINT or SIGTERM, exiting\n", getpid() );
 
     if( ( writeLog( LOG_NOTICE, "ifchk caught SIGINT or SIGTERM, exiting\n" ) ) != 0 )
     {
